@@ -2,8 +2,6 @@
 ( echo 'you need to change: Driver       "nv"' )
 ( echo '                to: Driver       "nvidia"' )
 ( echo in your /etc/X11/xorg.conf )
+( depmod -aq )
 ( cd usr/lib ; rm -rf libGL.so )
 ( cd usr/lib ; ln -sf libGL.so.1.0.8178 libGL.so )
-( cd usr/X11R6/lib/modules/extensions ; rm -rf libglx.so )
-( cd usr/X11R6/lib/modules/extensions ; ln -sf libglx.so.1.0.8178 libglx.so )
-( depmod -aq )
\ No newline at end of file
